@@ -12,5 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-from fastestimator.dataset.data import breast_cancer, cifar10, cub200, food101, horse2zebra, imdb_review, mendeley, \
-    mnist, montgomery, mscoco, nih_chestxray, omniglot, penn_treebank, shakespeare, svhn, usps
+from fastestimator.dataset.data import breast_cancer, cifair10, cifair100, cifar10, cifar100, cub200, food101, \
+    horse2zebra, imdb_review,  mendeley, mitmovie_ner, mnist, montgomery, mscoco, nih_chestxray, omniglot, \
+    penn_treebank, shakespeare, svhn, usps
