@@ -22,6 +22,8 @@ from fastestimator.dataset.numpy_dataset import NumpyDataset
 def load_data(image_key: str = "x", label_key: str = "y") -> Tuple[NumpyDataset, NumpyDataset]:
     """Load and return the CIFAR10 dataset.
 
+    Please consider using the ciFAIR10 dataset instead. CIFAR10 contains duplicates between its train and test sets.
+
     Args:
         image_key: The key for image.
         label_key: The key for label.
@@ -29,6 +31,7 @@ def load_data(image_key: str = "x", label_key: str = "y") -> Tuple[NumpyDataset,
     Returns:
         (train_data, eval_data)
     """
+    print("\033[93m {}\033[00m".format("FastEstimator-Warn: Consider using the ciFAIR10 dataset instead."))
     (x_train, y_train), (x_eval, y_eval) = tf.keras.datasets.cifar10.load_data()
     train_data = NumpyDataset({image_key: x_train, label_key: y_train})
     eval_data = NumpyDataset({image_key: x_eval, label_key: y_eval})
