@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
+import functools
 import inspect
 from typing import Any, Callable, Dict, List, Optional, Set, Tuple, TypeVar, Union
 
@@ -35,17 +36,28 @@ class Repeat(TensorOp):
         repeat: How many times to repeat the `op`. This can also be a function return, in which case the function input
             names will be matched to keys in the data dictionary, and the `op` will be repeated until the function
             evaluates to False. The function evaluation will happen at the end of a forward call, so the `op` will
-            always be evaluated at least once.
+            always be evaluated at least once. If a function is provided, any TF ops which are wrapped by Repeat will
+            not have access to the gradient tape, nor to previously deferred model update functions.
+        max_iter: A limit to how many iterations will be run (or None for no limit).
 
     Raises:
-        ValueError: If `repeat` or `op` are invalid.
+        ValueError: If `repeat`, `op`, or max_iter are invalid.
     """
-    def __init__(self, op: TensorOp, repeat: Union[int, Callable[..., bool]] = 1) -> None:
+    def __init__(self, op: TensorOp, repeat: Union[int, Callable[..., bool]] = 1,
+                 max_iter: Optional[int] = None) -> None:
         self.repeat_inputs = []
         extra_reqs = []
+        if max_iter is None:
+            self.max_iter = max_iter
+        else:
+            if max_iter < 1:
+                raise ValueError(f"Repeat requires max_iter to be >=1, but got {max_iter}")
+            self.max_iter = max_iter - 1  # -1 b/c the first invocation happens outside the while loop
         if isinstance(repeat, int):
             if repeat < 1:
                 raise ValueError(f"Repeat requires repeat to be >= 1, but got {repeat}")
+            if max_iter:
+                raise ValueError("Do not set max_iter when repeat is an integer")
         else:
             self.repeat_inputs.extend(inspect.signature(repeat).parameters.keys())
             extra_reqs = list(set(self.repeat_inputs) - set(op.outputs))
@@ -59,8 +71,8 @@ class Repeat(TensorOp):
     def op(self) -> TensorOp:
         return self.ops[0]
 
-    def build(self, framework: str) -> None:
-        self.op.build(framework)
+    def build(self, framework: str, device: Optional[torch.device] = None) -> None:
+        self.op.build(framework, device)
         if framework == 'tf':
             self.while_fn = self._tf_while
         else:
@@ -110,8 +122,12 @@ class Repeat(TensorOp):
         Returns:
             A reference to the updated data dictionary.
         """
+        i = 0
         while self.repeat(*[data[var_name] for var_name in self.repeat_inputs]):
+            if self.max_iter and i >= self.max_iter:
+                break
             BaseNetwork._forward_batch(data, state, self.ops)
+            i += 1
         return data
 
     def _tf_while(self, data: Dict[str, Tensor], state: Dict[str, Any]) -> Dict[str, Tensor]:
@@ -124,11 +140,13 @@ class Repeat(TensorOp):
         Returns:
             A reference to the updated data dictionary.
         """
-        args = ([data[var_name] for var_name in self.repeat_inputs], data, state)
-        args = tf.while_loop(self._tf_cond, self._tf_body, args)
+        args = ([data[var_name] for var_name in self.repeat_inputs], data)
+        # Use functools.partial since state may contain objects which cannot be cast to tensors (ex. gradient tape)
+        args = tf.while_loop(self._tf_cond, functools.partial(self._tf_body, state=state), args,
+                             maximum_iterations=self.max_iter)
         return args[1]
 
-    def _tf_cond(self, cnd: List[Tensor], data: Dict[str, Tensor], state: Dict[str, Any]) -> bool:
+    def _tf_cond(self, cnd: List[Tensor], data: Dict[str, Tensor]) -> bool:
         """A helper function determine whether to keep invoking the while method.
 
         Note that `data` and `state` are unused here, but required since tf.while_loop needs the cond and body to have
@@ -137,7 +155,6 @@ class Repeat(TensorOp):
         Args:
             cnd: A list of arguments to be passed to the condition function.
             data: A data dictionary to be used during looping.
-            state: The state variables to be considered during looping.
 
         Returns:
             Whether to continue looping.
@@ -145,7 +162,7 @@ class Repeat(TensorOp):
         return self.repeat(*cnd)
 
     def _tf_body(self, cnd: List[Tensor], data: Dict[str, Tensor],
-                 state: Dict[str, Any]) -> Tuple[List[Tensor], Dict[str, Tensor], Dict[str, Any]]:
+                 state: Dict[str, Any]) -> Tuple[List[Tensor], Dict[str, Tensor]]:
         """A helper function to execute the body of a while method.
 
         Note that `cnd` is unused here, but required since tf.while_loop needs the cond and body to have the same input
@@ -160,4 +177,4 @@ class Repeat(TensorOp):
             The updated `cnd` values, along with the modified data and state dictionaries.
         """
         BaseNetwork._forward_batch(data, state, self.ops)
-        return [data[var_name] for var_name in self.repeat_inputs], data, state
+        return [data[var_name] for var_name in self.repeat_inputs], data
