@@ -23,9 +23,9 @@ from datetime import datetime
 from pathlib import Path
 from typing import Any, Dict, Iterable, List, Optional, Type
 
+import tensorflow.keras.mixed_precision as mixed_precision
 import torch
 from prettytable import PrettyTable, from_db_cursor
-from tensorflow.keras.mixed_precision import experimental as mixed_precision
 
 from fastestimator.schedule.schedule import Scheduler
 from fastestimator.summary.system import System
@@ -94,6 +94,7 @@ _MAKE_FEAT_ENTRY = "INSERT INTO features (feature, fk) VALUES (:feature, :fk)"
 _MAKE_DS_ENTRY = "INSERT INTO datasets (mode, dataset, fk) VALUES (:mode, :dataset, :fk)"
 _MAKE_PIPE_ENTRY = "INSERT INTO pipeline (pipe_op, fk) VALUES (:op, :fk)"
 _MAKE_NET_ENTRY = "INSERT INTO network (net_op, fk) VALUES (:op, :fk)"
+_MAKE_PP_ENTRY = "INSERT INTO postprocess (pp_op, fk) VALUES (:op, :fk)"
 _MAKE_TRACE_ENTRY = "INSERT INTO traces (trace, fk) VALUES (:op, :fk)"
 # It would be nice to use a single INSERT ON CONFLICT call here, but Ubuntu 18 apt-get ships version 3.22.0 of sqlite
 # and the new syntax wasn't added until 3.24.0
@@ -247,6 +248,7 @@ class HistoryRecorder:
             self.db.executemany(_MAKE_DS_ENTRY, self._get_datasets_in_use())
             self.db.executemany(_MAKE_PIPE_ENTRY, self._get_items_in_use(self.system.pipeline.ops))
             self.db.executemany(_MAKE_NET_ENTRY, self._get_items_in_use(self.system.network.ops))
+            self.db.executemany(_MAKE_PP_ENTRY, self._get_items_in_use(self.system.network.postprocessing))
             self.db.executemany(_MAKE_TRACE_ENTRY, self._get_items_in_use(self.system.traces))
             self.db.execute(_MAKE_LOG_ENTRY, {'log': '', 'fk': self.pk})
             self.db.commit()
