@@ -216,6 +216,12 @@ class Traceability(Trace):
             with self.doc.create(Figure(position='h!')) as plot:
                 plot.add_image(os.path.relpath(log_path, start=self.save_dir),
                                width=NoEscape(r'1.0\textwidth,height=0.95\textheight,keepaspectratio'))
+            for idx, graph in enumerate(self.system.custom_graphs.values()):
+                graph_path = os.path.join(self.resource_dir, f'{self.report_name}_custom_graph_{idx}.png')
+                visualize_logs(experiments=graph, save_path=graph_path, verbose=False)
+                with self.doc.create(Figure(position='h!')) as plot:
+                    plot.add_image(os.path.relpath(graph_path, start=self.save_dir),
+                                   width=NoEscape(r'1.0\textwidth,height=0.95\textheight,keepaspectratio'))
 
     def _document_fe_graph(self) -> None:
         """Add FE execution graphs into the traceability document.
@@ -517,6 +523,7 @@ class Traceability(Trace):
         pipe_ops = get_current_items(self.system.pipeline.ops, run_modes=mode, epoch=epoch) if isinstance(
             ds, Dataset) else []
         net_ops = get_current_items(self.system.network.ops, run_modes=mode, epoch=epoch)
+        net_post = get_current_items(self.system.network.postprocessing, run_modes=mode, epoch=epoch)
         traces = sort_traces(get_current_items(self.system.traces, run_modes=mode, epoch=epoch))
         diagram = pydot.Dot(compound='true')  # Compound lets you draw edges which terminate at sub-graphs
         diagram.set('rankdir', 'TB')
@@ -532,10 +539,12 @@ class Traceability(Trace):
             batch_size = self.system.pipeline.batch_size
             if isinstance(batch_size, Scheduler):
                 batch_size = batch_size.get_current_value(epoch)
+            if isinstance(batch_size, dict):
+                batch_size = batch_size[mode]
             if batch_size is not None:
                 batch_size = f" (Batch Size: {batch_size})"
         self._draw_subgraph(diagram, diagram, label_last_seen, f'Pipeline{batch_size}', pipe_ops)
-        self._draw_subgraph(diagram, diagram, label_last_seen, 'Network', net_ops)
+        self._draw_subgraph(diagram, diagram, label_last_seen, 'Network', net_ops + net_post)
         self._draw_subgraph(diagram, diagram, label_last_seen, 'Traces', traces)
         return diagram
 
