@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-from typing import Set, Union
+from typing import Any, Dict, Set, Union
 
 import numpy as np
 from sklearn.metrics import confusion_matrix
@@ -35,16 +35,23 @@ class ConfusionMatrix(Trace):
             regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
             like "!infer" or "!train".
         output_name: Name of the key to store to the state.
+        **kwargs: Additional keyword arguments that pass to sklearn.metrics.confusion_matrix()
+
+    Raises:
+        ValueError: One of ["y_pred", "y_true", "labels"] argument exists in `kwargs`.
     """
     def __init__(self,
                  true_key: str,
                  pred_key: str,
                  num_classes: int,
                  mode: Union[str, Set[str]] = ("eval", "test"),
-                 output_name: str = "confusion_matrix") -> None:
+                 output_name: str = "confusion_matrix",
+                 **kwargs) -> None:
+        ConfusionMatrix.check_kwargs(kwargs)
         super().__init__(inputs=(true_key, pred_key), outputs=output_name, mode=mode)
         self.num_classes = num_classes
         self.matrix = None
+        self.kwargs = kwargs
 
     @property
     def true_key(self) -> str:
@@ -67,7 +74,7 @@ class ConfusionMatrix(Trace):
             y_pred = np.round(y_pred)
         assert y_pred.size == y_true.size
 
-        batch_confusion = confusion_matrix(y_true, y_pred, labels=list(range(0, self.num_classes)))
+        batch_confusion = confusion_matrix(y_true, y_pred, labels=list(range(0, self.num_classes)), **self.kwargs)
 
         if self.matrix is None:
             self.matrix = batch_confusion
@@ -76,3 +83,20 @@ class ConfusionMatrix(Trace):
 
     def on_epoch_end(self, data: Data) -> None:
         data.write_with_log(self.outputs[0], self.matrix)
+
+    @staticmethod
+    def check_kwargs(kwargs: Dict[str, Any]) -> None:
+        """Check if `kwargs` has any blacklist argument and raise an error if it does.
+
+        Args:
+            kwargs: Keywork arguments to be examined.
+
+        Raises:
+            ValueError: One of ["y_pred", "y_true", "labels"] argument exists in `kwargs`.
+        """
+        blacklist = ["y_true", "y_pred", "labels"]
+        illegal_kwarg = [x for x in blacklist if x in kwargs]
+        if illegal_kwarg:
+            raise ValueError(
+                f"Arguments {illegal_kwarg} cannot exist in kwargs, since FastEstimator will later directly use them in"
+                " sklearn.metrics.confusion_matrix()")
