@@ -18,16 +18,18 @@ from io import StringIO
 import numpy as np
 import tensorflow as tf
 import torch
+from tensorflow.python.autograph.impl.api import StagingError
 from torch.utils.data import DataLoader, Dataset
 
 import fastestimator as fe
 from fastestimator.architecture.pytorch.lenet import LeNet as LeNetTorch
 from fastestimator.architecture.tensorflow.lenet import LeNet as LeNetTf
 from fastestimator.dataset.data import mnist
+from fastestimator.network import TFNetwork
 from fastestimator.op.tensorop import TensorOp
 from fastestimator.op.tensorop.loss import CrossEntropy
 from fastestimator.op.tensorop.model import ModelOp, UpdateOp
-from fastestimator.schedule.schedule import get_current_items
+from fastestimator.schedule.schedule import EpochScheduler, get_current_items
 from fastestimator.trace import Trace
 
 
@@ -113,7 +115,7 @@ class TestEstimatorPrepareTraces(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         train_data, eval_data = mnist.load_data()
-        cls.pipeline = fe.Pipeline(train_data=train_data, eval_data=eval_data)
+        cls.pipeline = fe.Pipeline(train_data=train_data, eval_data=eval_data, test_data=eval_data)
 
         model = fe.build(model_fn=LeNetTf, optimizer_fn="adam")
 
@@ -123,7 +125,7 @@ class TestEstimatorPrepareTraces(unittest.TestCase):
             UpdateOp(model=model, loss_name="ce")
         ])
 
-    def test_estimator_prepare_traces_check_add_trace(self):
+    def test_estimator_prepare_traces_check_add_trace_fit_mode(self):
         est = fe.Estimator(pipeline=self.pipeline, network=self.network, epochs=1)
         est._prepare_traces({"train", "eval"})
 
@@ -136,11 +138,21 @@ class TestEstimatorPrepareTraces(unittest.TestCase):
         with self.subTest("check EvalEssential"):
             self.assertIsInstance(est.traces_in_use[1], fe.trace.EvalEssential)
 
+    def test_estimator_prepare_traces_check_add_trace_test_mode(self):
+        est = fe.Estimator(pipeline=self.pipeline, network=self.network, epochs=1)
+        est._prepare_traces({"test"})
+
+        with self.subTest("check Logger"):
+            self.assertIsInstance(est.traces_in_use[-1], fe.trace.Logger)
+
+        with self.subTest("check TestEssential"):
+            self.assertIsInstance(est.traces_in_use[0], fe.trace.TestEssential)
+
     def test_estimator_prepare_traces_check_all_trace_have_system(self):
         est = fe.Estimator(pipeline=self.pipeline, network=self.network, epochs=1)
-        est._prepare_traces({"train", "eval"})
+        est._prepare_traces({"train", "eval", "test"})
 
-        for trace in get_current_items(est.traces_in_use, run_modes={"train", "eval"}):
+        for trace in get_current_items(est.traces_in_use, run_modes={"train", "eval", "test"}):
             self.assertEqual(trace.system, est.system)
 
 
@@ -167,7 +179,11 @@ class TestEstimatorConfigureLoader(unittest.TestCase):
         new_loader = est._configure_loader(loader)
 
         with self.subTest("check loader type"):
-            self.assertIsInstance(new_loader, tf.data.Dataset)
+            strategy = tf.distribute.get_strategy()
+            if isinstance(strategy, tf.distribute.MirroredStrategy):
+                self.assertIsInstance(new_loader, tf.distribute.DistributedDataset)
+            else:
+                self.assertIsInstance(new_loader, tf.data.Dataset)
 
         with self.subTest("max_train_steps_per_epoch=3"):
             iterator = iter(new_loader)
@@ -194,7 +210,11 @@ class TestEstimatorConfigureLoader(unittest.TestCase):
         new_loader = est._configure_loader(loader)
 
         with self.subTest("check loader type"):  # it didn't change the data type
-            self.assertIsInstance(new_loader, tf.data.Dataset)
+            strategy = tf.distribute.get_strategy()
+            if isinstance(strategy, tf.distribute.MirroredStrategy) and isinstance(network, TFNetwork):
+                self.assertIsInstance(new_loader, tf.distribute.DistributedDataset)
+            else:
+                self.assertIsInstance(new_loader, tf.data.Dataset)
 
         with self.subTest("max_train_steps_per_epoch=3"):
             iterator = iter(new_loader)
@@ -227,7 +247,7 @@ class TestEstimatorConfigureTensor(unittest.TestCase):
         batch = est._configure_tensor(loader, batch)
         self.assertIsInstance(batch["x"], torch.Tensor)
 
-    def test_estimator_configure_tensor_tf_dataset_torch_model(self):
+    def test_estimator_configure_tensor_tf_dataset_tf_model(self):
         loader = get_sample_torch_dataloader()
         pipeline = fe.Pipeline(train_data=loader)
         model = fe.build(model_fn=LeNetTf, optimizer_fn="adam")
@@ -255,22 +275,36 @@ class TestEstimatorWarmup(unittest.TestCase):
         model = fe.build(model_fn=LeNetTf, optimizer_fn="adam")
 
         network = fe.Network(ops=[
-            ModelOp(model=model, inputs="x_out", outputs="y_pred")  # miss key x_out
+            EpochScheduler({
+                1: ModelOp(model=model, inputs="x_out", outputs="y_pred"),
+                2: ModelOp(model=model, inputs="x_out", outputs="y_pred")
+            })  # miss key x_out
         ])
 
-        est = fe.Estimator(pipeline=pipeline, network=network, epochs=1)
+        est = fe.Estimator(pipeline=pipeline, network=network, epochs=2)
         est._prepare_traces(run_modes={"train", "eval"})
-        with self.assertRaises(KeyError):
-            est._warmup(warmup=True)
+
+        strategy = tf.distribute.get_strategy()
+        if isinstance(strategy, tf.distribute.MirroredStrategy):
+            with self.assertRaises(StagingError):
+                est._warmup(warmup=True)
+        else:
+            with self.assertRaises(KeyError):
+                est._warmup(warmup=True)
 
     def test_estimator_warmup_trace_missing_key(self):
         loader = get_sample_tf_dataset()
         pipeline = fe.Pipeline(train_data=loader)  # "x", "y"
         model = fe.build(model_fn=LeNetTf, optimizer_fn="adam")
 
-        network = fe.Network(ops=[ModelOp(model=model, inputs="x", outputs="y_pred")])
+        network = fe.Network(ops=[
+            EpochScheduler({
+                1: ModelOp(model=model, inputs="x", outputs="y_pred"),
+                2: ModelOp(model=model, inputs="x", outputs="y_pred")
+            })  # miss key x_out
+        ])
 
-        est = fe.Estimator(pipeline=pipeline, network=network, epochs=1, traces=[Trace(inputs="z")])  # miss key "z"
+        est = fe.Estimator(pipeline=pipeline, network=network, epochs=2, traces=[Trace(inputs="z")])  # miss key "z"
         est._prepare_traces(run_modes={"train", "eval"})
         with self.assertRaises(AssertionError):
             est._warmup(warmup=True)
@@ -279,9 +313,7 @@ class TestEstimatorWarmup(unittest.TestCase):
         loader = get_sample_tf_dataset(expand_axis=1)
         pipeline = fe.Pipeline(train_data=loader)  # "x", "y"
         model = fe.build(model_fn=LeNetTorch, optimizer_fn="adam")
-
         network = fe.Network(ops=[ModelOp(model=model, inputs="x", outputs="y_pred")])
-
         est = fe.Estimator(pipeline=pipeline, network=network, epochs=1, traces=[Trace(inputs="y_pred")])
         est._prepare_traces(run_modes={"train", "eval"})
         est._warmup(warmup=True)
@@ -368,6 +400,13 @@ class TestEstimatorFit(unittest.TestCase):
         ops2 = [ShoutNameOp(name="A", iostream=iostream2), ShoutNameOp(name="B", iostream=iostream2)]
         traces2 = [ShoutNameTrace(name="a", iostream=iostream2), ShoutNameTrace(name="b", iostream=iostream2)]
 
+        # determine if running environment is multi-gpu (only needed for tf backend)
+        strategy = tf.distribute.get_strategy()
+        if isinstance(strategy, tf.distribute.MirroredStrategy):
+            device_count = len(tf.config.list_physical_devices(device_type="GPU"))
+        else:
+            device_count = 1
+
         for trace in traces2:
             trace.on_begin(None)
         for epoch in range(epochs):
@@ -377,9 +416,11 @@ class TestEstimatorFit(unittest.TestCase):
                 for trace in traces2:
                     trace.on_batch_begin(None)
                 if batch == 0:
-                    # ShoutOutTrace will only be invoked once while building static graph (for tf backend)
-                    for op in ops2:
-                        op.forward(None, None)
+                    # ShoutOutTrace will only be invoked the number of times equal to device count while building static
+                    # graph (for tf backend). ex: 4 GPU -> 4 times, CPU -> 1 time
+                    for _ in range(device_count):
+                        for op in ops2:
+                            op.forward(None, None)
                 for trace in traces2:
                     trace.on_batch_end(None)
             for trace in traces2:
@@ -466,6 +507,13 @@ class TestEstimatorTest(unittest.TestCase):
         ops2 = [ShoutNameOp(name="A", iostream=iostream2), ShoutNameOp(name="B", iostream=iostream2)]
         traces2 = [ShoutNameTrace(name="a", iostream=iostream2), ShoutNameTrace(name="b", iostream=iostream2)]
 
+        # determine if running environment is multi-gpu (only needed in tf backend)
+        strategy = tf.distribute.get_strategy()
+        if isinstance(strategy, tf.distribute.MirroredStrategy):
+            device_count = len(tf.config.list_physical_devices(device_type="GPU"))
+        else:
+            device_count = 1
+
         for trace in traces2:
             trace.on_begin(None)
         for epoch in range(epochs):
@@ -475,9 +523,11 @@ class TestEstimatorTest(unittest.TestCase):
                 for trace in traces2:
                     trace.on_batch_begin(None)
                 if batch == 0:
-                    # ShoutOutTrace will only be invoked once while building static graph (for tf backend)
-                    for op in ops2:
-                        op.forward(None, None)
+                    # ShoutOutTrace will only be invoked the number of times equal to device count while building static
+                    # graph (for tf backend). ex: 4 GPU -> 4 times, CPU -> 1 time
+                    for _ in range(device_count):
+                        for op in ops2:
+                            op.forward(None, None)
                 for trace in traces2:
                     trace.on_batch_end(None)
             for trace in traces2:
